Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: chrome/browser/net/sqlite_origin_bound_cert_store.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/io_thread.cc ('k') | chrome/browser/net/sqlite_origin_bound_cert_store.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/net/sqlite_origin_bound_cert_store.h
diff --git a/chrome/browser/net/sqlite_origin_bound_cert_store.h b/chrome/browser/net/sqlite_origin_bound_cert_store.h
index 8ade51e54a958b4eda3743903badac1f91dea5bc..b013462a64eb1639a1866d16b9454cc61ad54a05 100644
--- a/chrome/browser/net/sqlite_origin_bound_cert_store.h
+++ b/chrome/browser/net/sqlite_origin_bound_cert_store.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -13,24 +13,24 @@
class FilePath;
// Implements the net::DefaultOriginBoundCertStore::PersistentStore interface
// in terms of a SQLite database. For documentation about the actual member
// functions consult the documentation of the parent class
-// |net::DefaultOriginBoundCertStore::PersistentCertStore|.
-class SQLiteOriginBoundCertStore
- : public net::DefaultOriginBoundCertStore::PersistentStore {
+// |net::DefaultServerBoundCertStore::PersistentCertStore|.
+class SQLiteServerBoundCertStore
+ : public net::DefaultServerBoundCertStore::PersistentStore {
public:
- explicit SQLiteOriginBoundCertStore(const FilePath& path);
- virtual ~SQLiteOriginBoundCertStore();
+ explicit SQLiteServerBoundCertStore(const FilePath& path);
+ virtual ~SQLiteServerBoundCertStore();
- // net::DefaultOriginBoundCertStore::PersistentStore implementation.
+ // net::DefaultServerBoundCertStore::PersistentStore implementation.
virtual bool Load(
- std::vector<net::DefaultOriginBoundCertStore::OriginBoundCert*>* certs)
+ std::vector<net::DefaultServerBoundCertStore::ServerBoundCert*>* certs)
OVERRIDE;
- virtual void AddOriginBoundCert(
- const net::DefaultOriginBoundCertStore::OriginBoundCert& cert) OVERRIDE;
- virtual void DeleteOriginBoundCert(
- const net::DefaultOriginBoundCertStore::OriginBoundCert& cert) OVERRIDE;
+ virtual void AddServerBoundCert(
+ const net::DefaultServerBoundCertStore::ServerBoundCert& cert) OVERRIDE;
+ virtual void DeleteServerBoundCert(
+ const net::DefaultServerBoundCertStore::ServerBoundCert& cert) OVERRIDE;
virtual void SetClearLocalStateOnExit(bool clear_local_state) OVERRIDE;
virtual void Flush(const base::Closure& completion_task) OVERRIDE;
@@ -39,7 +39,7 @@ class SQLiteOriginBoundCertStore
scoped_refptr<Backend> backend_;
- DISALLOW_COPY_AND_ASSIGN(SQLiteOriginBoundCertStore);
+ DISALLOW_COPY_AND_ASSIGN(SQLiteServerBoundCertStore);
};
#endif // CHROME_BROWSER_NET_SQLITE_ORIGIN_BOUND_CERT_STORE_H_
« no previous file with comments | « chrome/browser/io_thread.cc ('k') | chrome/browser/net/sqlite_origin_bound_cert_store.cc » ('j') | no next file with comments »
@@ -13,24 +13,24 @@
class FilePath;
-// Implements the net::DefaultOriginBoundCertStore::PersistentStore interface
+// Implements the net::DefaultServerBoundCertStore::PersistentStore interface
// in terms of a SQLite database. For documentation about the actual member
// functions consult the documentation of the parent class

Powered by Google App Engine
This is Rietveld 408576698